pub struct TextMessage {
pub role: String,
pub content: String,
pub name: Option<String>,
pub reasoning_content: Option<String>,
}Expand description
Plain role/content message.
Fields
role: StringRequest-side roles remain free-form strings so callers can use DeepSeek-compatible
extensions such as developer without waiting for a curated enum surface.
content: Stringname: Option<String>reasoning_content: Option<String>Trait Implementations
Sourceimpl Clone for TextMessage
impl Clone for TextMessage
Sourcefn clone(&self) -> TextMessage
fn clone(&self) -> TextMessage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TextMessage
impl Debug for TextMessage
Sourceimpl<'de> Deserialize<'de> for TextMessage
impl<'de> Deserialize<'de> for TextMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TextMessage
impl PartialEq for TextMessage
Sourcefn eq(&self, other: &TextMessage) -> bool
fn eq(&self, other: &TextMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TextMessage
impl Serialize for TextMessage
impl StructuralPartialEq for TextMessage